@@ -195,6 +195,7 @@ bonobo_dock_item_class_init (BonoboDockItemClass *class)
 			     GTK_SHADOW_OUT,
 			     (G_PARAM_READABLE |
 			      G_PARAM_WRITABLE)));
+
   g_object_class_install_property (
 	  gobject_class,
 	  PROP_ORIENTATION,
@@ -205,6 +206,7 @@ bonobo_dock_item_class_init (BonoboDockItemClass *class)
 			     GTK_ORIENTATION_HORIZONTAL,
 			     (G_PARAM_READABLE |
 			      G_PARAM_WRITABLE)));
+
   g_object_class_install_property (
 	  gobject_class,
 	  PROP_PREFERRED_WIDTH,
@@ -212,8 +214,8 @@ bonobo_dock_item_class_init (BonoboDockItemClass *class)
 			     _("Preferred width"),
 			     _("Preferred width"),
 			     0, G_MAXINT, 0,
-			     (G_PARAM_READABLE |
-			      G_PARAM_WRITABLE)));
+			     G_PARAM_READABLE));
+
   g_object_class_install_property (
 	  gobject_class,
 	  PROP_PREFERRED_HEIGHT,
@@ -221,8 +223,7 @@ bonobo_dock_item_class_init (BonoboDockItemClass *class)
 			     _("Preferred height"),
 			     _("Preferred height"),
 			     0, G_MAXINT, 0,
-			     (G_PARAM_READABLE |
-			      G_PARAM_WRITABLE)));
+			     G_PARAM_READABLE));
 
   dock_item_signals[DOCK_DRAG_BEGIN] =
 	  g_signal_new ("dock_drag_begin",
@@ -1233,14 +1234,14 @@ bonobo_dock_item_grab_pointer (BonoboDockItem *item)
                            fleur,
                            GDK_CURRENT_TIME) != 0);
 
-  gdk_cursor_destroy (fleur);
+  gdk_cursor_unref (fleur);
 }
 
 gboolean
 bonobo_dock_item_detach (BonoboDockItem *item, gint x, gint y)
 {
-  GtkRequisition requisition;
   GtkAllocation allocation;
+  GtkRequisition requisition;
 
   if (item->behavior & BONOBO_DOCK_ITEM_BEH_NEVER_FLOATING)
     return FALSE;
@@ -1259,7 +1260,8 @@ bonobo_dock_item_detach (BonoboDockItem *item, gint x, gint y)
                           x, y, requisition.width, requisition.height);
 
   gdk_window_reparent (item->bin_window, item->float_window, 0, 0);
-  gdk_window_set_hints (item->float_window, x, y, 0, 0, 0, 0, GDK_HINT_POS);
+	  
+/*  gdk_window_set_hints (item->float_window, x, y, 0, 0, 0, 0, GDK_HINT_POS); */
 
   gdk_window_show (item->float_window);
   item->float_window_mapped = TRUE;
