@@ -4,8 +4,9 @@
  *
  * Authors:
  *    Jacob Berkman  <jacob@ximian.com>
+ *    Paolo Maggi  <maggi@athena.polito.it>
  *
- * Copyright 2001 Ximian, Inc.
+ * Copyright 2001-2002 Ximian, Inc.
  *
  */
 
@@ -25,6 +26,7 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkeditable.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 #include <bonobo/bonobo-i18n.h>
 
@@ -37,11 +39,7 @@ typedef enum {
 	FILESEL_SAVE
 } FileselMode;
 
-/* Take in sync with gtkfilesel.c */
-enum {
-  FILE_COLUMN
-};
-
+static GQuark user_data_id = 0;
 
 static gint
 delete_file_selector (GtkWidget *d, GdkEventAny *e, gpointer data)
@@ -84,10 +82,12 @@ listener_cb (BonoboListener *listener,
 		for (i = 0; i < seq->_length; i++)
 			strv[i] = g_strdup (seq->_buffer[i]);
 		strv[i] = NULL;
-		gtk_object_set_user_data (GTK_OBJECT (dialog), strv);
+		g_object_set_qdata (G_OBJECT (dialog),
+				    user_data_id, strv);
 	} else 
-		gtk_object_set_user_data (GTK_OBJECT (dialog),
-					  g_strdup (seq->_buffer[0]));
+		g_object_set_qdata (G_OBJECT (dialog),
+				    user_data_id,
+				    g_strdup (seq->_buffer[0]));
 
  cancel_clicked:
 	g_free (subtype);
@@ -198,68 +198,20 @@ ok_clicked_cb (GtkWidget *widget, gpointer data)
 		}
 		gtk_file_selection_set_filename (fsel, dir_name);
 		g_free (dir_name);
+
 	} else if (GET_MODE (fsel) == FILESEL_OPEN_MULTI) {
-
-		GtkTreeSelection *selection;
-		GtkTreeModel *model;
-		GtkTreeIter iter;
+		gchar **strv = gtk_file_selection_get_selections (fsel);
 		
-		char *filedirname;
-		char **strv;
-		int rows, i;
-
-		gtk_widget_hide (GTK_WIDGET (fsel));
-
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW (GTK_FILE_SELECTION (fsel)->file_list));	
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (GTK_FILE_SELECTION (fsel)->file_list));	
-
-		rows = 	gtk_tree_model_iter_n_children (model, NULL);
-
-		strv = g_new (char *, rows + 2);
-		strv[rows] = g_strdup (file_name);
-
-		if (!gtk_tree_model_get_iter_root (model, &iter))
-			return;
-
-		filedirname = g_path_get_dirname (file_name);
-		
-		i = 0;
-		
-		do {
-			if (gtk_tree_selection_iter_is_selected (selection, &iter))
-			{	
-		      		gchar *f;
-      
-      				gtk_tree_model_get (model, &iter, FILE_COLUMN, &f, -1);
-				strv[i] = concat_dir_and_file (filedirname, f);
-				
-				g_free (f);
-
-				/* avoid duplicates */
-				if (strv[rows] && (strcmp (strv[i], strv[rows]) == 0)) {
-					g_free (strv[rows]);
-					strv[rows] = NULL;
-				}
-
-				++i;
-			}
-		} while (gtk_tree_model_iter_next (model, &iter));
-
-		strv[i] = strv[rows];
-		strv[i + 1] = NULL;
-
-		strv = g_renew (char *, strv, i + 2);
-
-		g_free (filedirname);
-
-		gtk_object_set_user_data (GTK_OBJECT (fsel), strv);
+		g_object_set_qdata (G_OBJECT (fsel),
+				    user_data_id, strv);
 		gtk_main_quit ();
 
 	} else {
 		gtk_widget_hide (GTK_WIDGET (fsel));
 
-		gtk_object_set_user_data (GTK_OBJECT (fsel),
-					  g_strdup (file_name));
+		g_object_set_qdata (G_OBJECT (fsel),
+				    user_data_id,
+				    g_strdup (file_name));
 		gtk_main_quit ();
 	}
 }
@@ -313,15 +265,8 @@ create_gtk_selector (FileselMode mode,
 
 	g_free (path);
 
-	if (mode == FILESEL_OPEN_MULTI) {
-		GtkTreeSelection *selection;
-
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (GTK_FILE_SELECTION (filesel)->file_list));	
-		/* FIXME: change GTK_SELECTION_SINGLE to GTK_SELECTION_MULTIPLE as soon as bug #70505
-		 * will be fixed -- Paolo
-		 */	
-		gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-	}
+	if (mode == FILESEL_OPEN_MULTI) 
+		gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION (filesel), TRUE);
 
 	return GTK_WINDOW (filesel);
 }
@@ -338,10 +283,17 @@ run_file_selector (GtkWindow  *parent,
 {
 	GtkWindow *dialog = NULL;
 	gpointer   retval;
+	gpointer   data;
+	gboolean   using_bonobo_filesel=FALSE;
+	
+	if (!user_data_id)
+		user_data_id = g_quark_from_static_string ("UserData");
 
-	if (!g_getenv ("GNOME_FILESEL_DISABLE_BONOBO"))
+	if (!g_getenv ("GNOME_FILESEL_DISABLE_BONOBO")) {
 		dialog = create_bonobo_selector (enable_vfs, mode, mime_types, 
 						 default_path, default_filename);
+		using_bonobo_filesel=TRUE;
+	}
 	if (!dialog)
 		dialog = create_gtk_selector (mode, default_path, default_filename);
 
@@ -361,7 +313,27 @@ run_file_selector (GtkWindow  *parent,
 
 	gtk_main ();
 
-	retval = gtk_object_get_user_data (GTK_OBJECT (dialog));
+	data = g_object_get_qdata (G_OBJECT (dialog), user_data_id);
+
+	if (enable_vfs && !using_bonobo_filesel &&
+			(mode != FILESEL_OPEN_MULTI)) {
+ 		retval = gnome_vfs_get_uri_from_local_path (data);
+ 		g_free (data);
+
+	} else if (enable_vfs && !using_bonobo_filesel &&
+			(mode == FILESEL_OPEN_MULTI)) {
+		gint i;
+		gchar **files = data;
+
+		for (i = 0; files[i]; ++i) {
+			gchar *tmp = files[i];
+			files[i] = gnome_vfs_get_uri_from_local_path (tmp);
+			g_free (tmp);
+		}
+
+		retval = files;
+ 	} else
+ 		retval = data;
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
