@@ -33,6 +33,11 @@ static GObjectClass *parent_class = NULL;
 #define MAGIC_RADIO_GROUP_KEY "Bonobo::RadioGroupName"
 #define UI_SYNC_MENU_KEY "Bonobo::UISyncMenu"
 
+static GQuark menu_id = 0;
+static GQuark popups_id = 0;
+static GQuark submenu_id = 0;
+static GQuark menuitem_id = 0;
+
 typedef struct {
 	GtkMenu          *menu;
 	char             *path;
@@ -623,13 +628,10 @@ impl_bonobo_ui_sync_menu_build (BonoboUISync     *sync,
 			
 			else
 				menu_widget = NULL;
-			
-			gtk_check_menu_item_set_show_toggle (
-				GTK_CHECK_MENU_ITEM (menu_widget), TRUE);
 
-			g_signal_connect (GTK_OBJECT (menu_widget), "toggled",
-					    (GtkSignalFunc) menu_toggle_emit_ui_event,
-					    engine);
+			g_signal_connect (menu_widget, "toggled",
+					  G_CALLBACK (menu_toggle_emit_ui_event),
+					  engine);
 
 			bonobo_ui_node_free_string (type);
 		} else {
@@ -852,8 +854,17 @@ static gboolean
 impl_bonobo_ui_sync_menu_can_handle (BonoboUISync *sync,
 				     BonoboUINode *node)
 {
-	return bonobo_ui_node_has_name (node, "menu") ||
-	       bonobo_ui_node_has_name (node, "popups");
+	if (!menu_id) {
+		menu_id = g_quark_from_static_string ("menu");
+		popups_id = g_quark_from_static_string ("popups");
+		submenu_id = g_quark_from_static_string ("submenu");
+		menuitem_id = g_quark_from_static_string ("menuitem");
+	}
+	
+	return (node->name_id == menu_id ||
+		node->name_id == popups_id ||
+		node->name_id == submenu_id ||
+		node->name_id == menuitem_id);
 }
 
 /* We need to map the shell to the item */
